@@ -5,6 +5,7 @@ use serde::{Deserialize, Serialize};
 use crate::{
     derivative::EffectivePosition, derivative::TrimmedDerivativeLimitOrder, derivative_market::FullDerivativeMarket,
     derivative_market::PerpetualMarketFunding, derivative_market::PerpetualMarketInfo, exchange::Deposit, route::InjectiveRoute,
+    spot::TrimmedSpotLimitOrder, spot_market::FullSpotMarket,
 };
 use cosmwasm_std::CustomQuery;
 
@@ -76,11 +77,6 @@ pub struct SubaccountEffectivePositionInMarketResponse {
     pub state: Option<EffectivePosition>,
 }
 
-#[derive(Serialize, Deserialize, Clone, Debug, PartialEq, JsonSchema)]
-pub struct TraderDerivativeOrdersResponse {
-    pub orders: Option<Vec<TrimmedDerivativeLimitOrder>>,
-}
-
 #[derive(Serialize, Deserialize, Clone, Debug, PartialEq, JsonSchema)]
 pub struct PerpetualMarketInfoResponse {
     pub info: Option<PerpetualMarketInfo>,
@@ -91,6 +87,16 @@ pub struct PerpetualMarketFundingResponse {
     pub state: Option<PerpetualMarketFunding>,
 }
 
+#[derive(Serialize, Deserialize, Clone, Debug, PartialEq, JsonSchema)]
+pub struct TraderDerivativeOrdersResponse {
+    pub orders: Option<Vec<TrimmedDerivativeLimitOrder>>,
+}
+
+#[derive(Serialize, Deserialize, Clone, Debug, PartialEq, JsonSchema)]
+pub struct TraderSpotOrdersResponse {
+    pub orders: Option<Vec<TrimmedSpotLimitOrder>>,
+}
+
 #[derive(Serialize, Deserialize, Clone, Debug, PartialEq, JsonSchema)]
 pub struct DerivativeMarketVolatilityResponse {
     pub volatility: Option<FPDecimal>,
@@ -105,3 +111,8 @@ pub struct SpotMarketVolatilityResponse {
 pub struct DerivativeMarketResponse {
     pub market: FullDerivativeMarket,
 }
+
+#[derive(Serialize, Deserialize, Clone, Debug, PartialEq, JsonSchema)]
+pub struct SpotMarketResponse {
+    pub market: FullSpotMarket,
+}
